@@ -10,9 +10,16 @@ function(
    if(!is.null(colnames)) colnames <- odfTranslate(colnames, toR = FALSE)
    xMat <- if(horizontal) as.matrix(t(x)) else as.matrix(x)
    colTypes <- apply(xMat, 2, odfDataType)
-   xChar <- format(xMat, ...)
 
-   if(is.null(styles))    styles <- tableStyles(xChar, useRowNames = FALSE, colnames)
+   theDots <- list(...)
+   if(!any(names(theDots) == "justify")) theDots$justify <- "none"
+   if(!any(names(theDots) == "trim")) theDots$trim <- TRUE
+   
+   args <- list(x = xMat)
+   args <- c(args, theDots)
+   xChar <- do.call("format", args)
+
+   if(is.null(styles)) styles <- tableStyles(xChar, useRowNames = FALSE, colnames)
 
    tbleText <- odfTableGen(xChar, colTypes, header = colnames, tableName = name, styles)
    structure(tbleText, class = "odfTable")
